==> bootstrap-sass-init-gulp-1.0.0.tgz: package/README.md <==
# Bootstrap - Sass - Init - Gulp

Plantilla para crear proyectos web Bootstrap con HTML5/CSS3 usando Saas y temas propios optimizando la tarea con Gulp incluyendo Font Awesome.

[![Bootstrap](https://img.shields.io/badge/Bootstrap-%20Ready-blue)](https://getbootstrap.com/)
[![Saas](https://img.shields.io/badge/Sass-%20Ready-ff69b4)](https://sass-lang.com/)
[![Gulp](https://img.shields.io/badge/Gulp-%20Ready-cf4647)](https://gulpjs.com/)
[![Licence](https://img.shields.io/github/license/joseluisgs/NodeMonRest)](https://github.com/joseluisgs/NodeMonRest/blob/master/LICENSE)
![GitHub](https://img.shields.io/github/last-commit/joseluisgs/bootstrap-sass-init)

## Acerca de

Platilla automatiazada para crear sitios web con Bootstrapt y cambiar su apariencia con Sass. Para ello se ha creado una serie de tareas automatizadas con [Gulp](https://gulpjs.com/) y se ha añadido [Font Awesome](https://fontawesome.com/).

## Funcionamiento con npm:

#### Setup y configuración de librerías

```bash
$npm install
```
#### Modo de desarrollo y live server

```bash
$npm start
$npm run serve
```

#### Limpieza de assets y directorio de distribición

```bash
$npm run clean
```

## Autor

Codificado con :sparkling_heart: por [José Luis González Sánchez](https://twitter.com/joseluisgonsan)

![Twitter](https://img.shields.io/twitter/follow/joseluisgonsan?style=social) ![GitHub](https://img.shields.io/github/followers/joseluisgs?style=social)

## Licencia

Este proyecto esta licenciado bajo licencia **MIT**, si desea saber más, visite el fichero [LICENSE](https://github.com/joseluisgs/bootstrap-sass-init-gulp/blob/master/LICENSE) para su uso docente y educativo.

==> bootstrap-sass-init-gulp-1.0.1.tgz: package/README.md <==
# Bootstrap - Sass - Init - Gulp

Plantilla para crear proyectos web Bootstrap con HTML5/CSS3 usando Saas y temas propios optimizando la tarea con Gulp incluyendo Font Awesome.

[![Bootstrap](https://img.shields.io/badge/Bootstrap-%20Ready-blue)](https://getbootstrap.com/)
[![Saas](https://img.shields.io/badge/Sass-%20Ready-ff69b4)](https://sass-lang.com/)
[![Gulp](https://img.shields.io/badge/Gulp-%20Ready-cf4647)](https://gulpjs.com/)
[![NPM](https://img.shields.io/badge/NPM-%20Ready-CE0000)](https://www.npmjs.com/package/bootstrap-sass-init-gulp)
[![Licence](https://img.shields.io/github/license/joseluisgs/bootstrap-sass-init-gulp)](https://github.com/joseluisgs/bootstrap-sass-init-gulp/blob/master/LICENSE)
![GitHub](https://img.shields.io/github/last-commit/joseluisgs/bootstrap-sass-init-gulp)

## Acerca de

Platilla automatiazada para crear sitios web con Bootstrapt y cambiar su apariencia con Sass. Para ello se ha creado una serie de tareas automatizadas con [Gulp](https://gulpjs.com/) y se ha añadido [Font Awesome](https://fontawesome.com/).

## Funcionamiento con npm:

#### Setup y configuración de librerías

```bash
$npm install
```

#### Modo de desarrollo y live server

```bash
$npm start
$npm run serve
```

#### Limpieza de assets y directorio de distribición

```bash
$npm run clean
```

## Autor

Codificado con :sparkling_heart: por [José Luis González Sánchez](https://twitter.com/joseluisgonsan)

![Twitter](https://img.shields.io/twitter/follow/joseluisgonsan?style=social) ![GitHub](https://img.shields.io/github/followers/joseluisgs?style=social)

## Licencia

Este proyecto esta licenciado bajo licencia **MIT**, si desea saber más, visite el fichero [LICENSE](https://github.com/joseluisgs/bootstrap-sass-init-gulp/blob/master/LICENSE) para su uso docente y educativo.
